Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as Dma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as FrameDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as ReadDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as RxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as TxDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as UpDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.
Get the DMA request number needed to use this channel as WriteDma.
Note: in some chips, ST calls this the “channel”, and calls channels “streams”.
embassy-stm32 always uses the “channel” and “request number” names.